// auth.route.ts
import express, { Request, Response } from "express";

import {
  checkEmalValidation,
  checkPhoneNumberValidation,
  checkUsernameValidation,
  emailVerifySendValidation,
  forgotPasswordValidation,
  forgotUsernameValidation,
  loginValidation,
  otpVerifyValidation,
  phoneVerifySendValidation,
  registrationChangeValidation,
  registrationValidation,
  resetPasswordTokenVerifyValidation,
  resetPasswordValidation,
} from "../helpers/auth.helper";
import {
  login,
  register,
  registerChange,
  emailOtpVerify,
  emailVerifySend,
  phoneOtpVerify,
  phoneVerifySend,
  checkUsername,
  generateSessionToken,
  forgotUsername,
  resetPassword,
  forgotPassword,
  checkEmail,
  checkPhoneNumber,
  resetPasswordTokenVerify,
} from "../controllers/auth.controller";
import { validateData } from "../middlewares/validationMiddleware";
import { authenticate } from "../middlewares";

export const authRouter = express.Router();

authRouter.post("/register", validateData(registrationValidation), register);

authRouter.put(
  "/register",
  validateData(registrationChangeValidation),
  registerChange
);

authRouter.post("/login", validateData(loginValidation), login);

authRouter.post("/generate-session", generateSessionToken);

authRouter.post(
  "/check-username",
  validateData(checkUsernameValidation),
  checkUsername
);

authRouter.post(
  "/check-email",
  validateData(checkEmalValidation),
  checkEmail
);

authRouter.post(
  "/check-phone-number",
  validateData(checkPhoneNumberValidation),
  checkPhoneNumber
);
authRouter.post("/forgot-username",
  validateData(forgotUsernameValidation),
  forgotUsername
);
authRouter.post("/forgot-password",
  validateData(forgotPasswordValidation),
  forgotPassword
);
authRouter.post("/reset-password",
  validateData(resetPasswordValidation),
  resetPassword
);

authRouter.post("/reset-password/token-verify",
  validateData(resetPasswordTokenVerifyValidation),
  resetPasswordTokenVerify
);


// OTP handle
authRouter.post(
  "/verify-email",
  validateData(emailVerifySendValidation),
  emailVerifySend
);

authRouter.put(
  "/verify-email",
  validateData(otpVerifyValidation),
  emailOtpVerify
);

authRouter.post(
  "/verify-phone",
  validateData(phoneVerifySendValidation),
  phoneVerifySend
);

authRouter.put(
  "/verify-phone",
  validateData(otpVerifyValidation),
  phoneOtpVerify
);

